@@ -3,9 +3,10 @@
 from __future__ import annotations
 
 from pathlib import Path
-from typing import Any, Literal, Sequence
+from typing import Any, List, Literal, Sequence
 
 import clack
+from clack.types import ClackRunner
 
 
 # TEST | Basic test of 'bar' subcommand.
@@ -65,6 +66,11 @@ FooCommand = Literal["foo"]
 Command = Literal[BarCommand, BazCommand, FooCommand]
 
 
+# The ALL_RUNNERS list is populated later by the `register_runner` decorator.
+ALL_RUNNERS: List[ClackRunner] = []
+register_runner = clack.register_runner_factory(ALL_RUNNERS)
+
+
 class Config(clack.Config):
     """Shared Configuration."""
 
@@ -116,18 +122,21 @@ def clack_parser(argv: Sequence[str]) -> dict[str, Any]:
     return vars(args)
 
 
+@register_runner
 def run_bar(cfg: BarConfig) -> int:
     """Runner function."""
     print(f"bar={cfg.bar}, barbar={cfg.barbar}")
     return 0
 
 
+@register_runner
 def run_baz(cfg: BazConfig) -> int:
     """Runner function."""
     print(f"baz={cfg.baz}")
     return 0
 
 
+@register_runner
 def run_foo(cfg: FooConfig) -> int:
     """Runner function."""
     print(f"foo={cfg.foo} foo_txt={cfg.foo_txt}")
@@ -135,5 +144,5 @@ def run_foo(cfg: FooConfig) -> int:
 
 
 main = clack.main_factory(
-    "subcommands", runners=[run_bar, run_baz, run_foo], parser=clack_parser
+    "subcommands", runners=ALL_RUNNERS, parser=clack_parser
 )
